==> zio-aws-route53recoverycontrolconfig_2.13-5.17.116.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/AssertionRuleUpdate.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max256PatternAZaZ09,
  __stringMin1Max64PatternS
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class AssertionRuleUpdate(
    name: __stringMin1Max64PatternS,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate = {
    import AssertionRuleUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
      .builder()
      .name(__stringMin1Max64PatternS.unwrap(name): java.lang.String)
      .safetyRuleArn(
        __stringMin1Max256PatternAZaZ09.unwrap(safetyRuleArn): java.lang.String
      )
      .waitPeriodMs(__integer.unwrap(waitPeriodMs): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate
      .wrap(buildAwsValue())
}
object AssertionRuleUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate =
      zio.aws.route53recoverycontrolconfig.model
        .AssertionRuleUpdate(name, safetyRuleArn, waitPeriodMs)
    def name: __stringMin1Max64PatternS
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def waitPeriodMs: __integer
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ) extends zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly {
    override val name: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.name())
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.safetyRuleArn())
    override val waitPeriodMs: __integer =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__integer(impl.waitPeriodMs())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ): zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.153.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/AssertionRuleUpdate.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max256PatternAZaZ09,
  __stringMin1Max64PatternS
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class AssertionRuleUpdate(
    name: __stringMin1Max64PatternS,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate = {
    import AssertionRuleUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
      .builder()
      .name(name: java.lang.String)
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .waitPeriodMs(waitPeriodMs: Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate
      .wrap(buildAwsValue())
}
object AssertionRuleUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate =
      zio.aws.route53recoverycontrolconfig.model
        .AssertionRuleUpdate(name, safetyRuleArn, waitPeriodMs)
    def name: __stringMin1Max64PatternS
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def waitPeriodMs: __integer
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ) extends zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly {
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      impl.safetyRuleArn(): __stringMin1Max256PatternAZaZ09
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRuleUpdate
  ): zio.aws.route53recoverycontrolconfig.model.AssertionRuleUpdate.ReadOnly =
    new Wrapper(impl)
}
